==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/bedget/bean/DesignestimatedetailEntity.java <==
package com.ejianc.business.bedget.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计概算子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_designestimatedetail")
public class DesignestimatedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="tid")
    private java.lang.String tid; // 表格行id
    @TableField(value="tpid")
    private java.lang.String tpid; // 表格行父id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="name")
    private java.lang.String name; // 名称
    @TableField(value="project_cost")
    private java.math.BigDecimal projectCost; // 项目造价
    @TableField(value="cost_percent")
    private java.math.BigDecimal costPercent; // 造价占比
    @TableField(value="project_scale")
    private BigDecimal projectScale; // 工程规模
    @TableField(value="unit_cost")
    private java.lang.String unitCost; // 单位造价
    @TableField(value="budge_total")
    private java.math.BigDecimal budgeTotal; // 预算书合计
    @TableField(value="labor_cost")
    private java.math.BigDecimal laborCost; // 人工费
    @TableField(value="material_cost")
    private java.math.BigDecimal materialCost; // 材料费
    @TableField(value="machinery_cost")
    private java.math.BigDecimal machineryCost; // 机械费
    @TableField(value="business_manager_cost")
    private java.math.BigDecimal businessManagerCost; // 企业管理费
    @TableField(value="profit")
    private java.math.BigDecimal profit; // 利润
    @TableField(value="measure_items_total")
    private java.math.BigDecimal measureItemsTotal; // 措施项目合计
    @TableField(value="safe_civilized_construction_cost")
    private java.math.BigDecimal safeCivilizedConstructionCost; // 安全文明施工费
    @TableField(value="transport_consume_cost")
    private java.math.BigDecimal transportConsumeCost; // 运输消纳费
    @TableField(value="scattered_expensese_total")
    private java.math.BigDecimal scatteredExpenseseTotal; // 零星费用合计
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费合计
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金合计
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="code")
    private java.lang.String code; // 编码
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 表格行id
     */
    public java.lang.String getTid() {
        return tid;
    }

    /**
     * 表格行id
     */
    public void setTid(java.lang.String tid) {
        this.tid = tid;
    }
    /**
     * 表格行父id
     */
    public java.lang.String getTpid() {
        return tpid;
    }

    /**
     * 表格行父id
     */
    public void setTpid(java.lang.String tpid) {
        this.tpid = tpid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 项目造价
     */
    public java.math.BigDecimal getProjectCost() {
        return projectCost;
    }

    /**
     * 项目造价
     */
    public void setProjectCost(java.math.BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    /**
     * 造价占比
     */
    public java.math.BigDecimal getCostPercent() {
        return costPercent;
    }

    /**
     * 造价占比
     */
    public void setCostPercent(java.math.BigDecimal costPercent) {
        this.costPercent = costPercent;
    }
    /**
     * 工程规模
     */
    public BigDecimal getProjectScale() {
        return projectScale;
    }

    /**
     * 工程规模
     */
    public void setProjectScale(BigDecimal projectScale) {
        this.projectScale = projectScale;
    }
    /**
     * 单位造价
     */
    public java.lang.String getUnitCost() {
        return unitCost;
    }

    /**
     * 单位造价
     */
    public void setUnitCost(java.lang.String unitCost) {
        this.unitCost = unitCost;
    }
    /**
     * 预算书合计
     */
    public java.math.BigDecimal getBudgeTotal() {
        return budgeTotal;
    }

    /**
     * 预算书合计
     */
    public void setBudgeTotal(java.math.BigDecimal budgeTotal) {
        this.budgeTotal = budgeTotal;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborCost() {
        return laborCost;
    }

    /**
     * 人工费
     */
    public void setLaborCost(java.math.BigDecimal laborCost) {
        this.laborCost = laborCost;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialCost() {
        return materialCost;
    }

    /**
     * 材料费
     */
    public void setMaterialCost(java.math.BigDecimal materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMachineryCost() {
        return machineryCost;
    }

    /**
     * 机械费
     */
    public void setMachineryCost(java.math.BigDecimal machineryCost) {
        this.machineryCost = machineryCost;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getBusinessManagerCost() {
        return businessManagerCost;
    }

    /**
     * 企业管理费
     */
    public void setBusinessManagerCost(java.math.BigDecimal businessManagerCost) {
        this.businessManagerCost = businessManagerCost;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfit() {
        return profit;
    }

    /**
     * 利润
     */
    public void setProfit(java.math.BigDecimal profit) {
        this.profit = profit;
    }
    /**
     * 措施项目合计
     */
    public java.math.BigDecimal getMeasureItemsTotal() {
        return measureItemsTotal;
    }

    /**
     * 措施项目合计
     */
    public void setMeasureItemsTotal(java.math.BigDecimal measureItemsTotal) {
        this.measureItemsTotal = measureItemsTotal;
    }
    /**
     * 安全文明施工费
     */
    public java.math.BigDecimal getSafeCivilizedConstructionCost() {
        return safeCivilizedConstructionCost;
    }

    /**
     * 安全文明施工费
     */
    public void setSafeCivilizedConstructionCost(java.math.BigDecimal safeCivilizedConstructionCost) {
        this.safeCivilizedConstructionCost = safeCivilizedConstructionCost;
    }
    /**
     * 运输消纳费
     */
    public java.math.BigDecimal getTransportConsumeCost() {
        return transportConsumeCost;
    }

    /**
     * 运输消纳费
     */
    public void setTransportConsumeCost(java.math.BigDecimal transportConsumeCost) {
        this.transportConsumeCost = transportConsumeCost;
    }
    /**
     * 零星费用合计
     */
    public java.math.BigDecimal getScatteredExpenseseTotal() {
        return scatteredExpenseseTotal;
    }

    /**
     * 零星费用合计
     */
    public void setScatteredExpenseseTotal(java.math.BigDecimal scatteredExpenseseTotal) {
        this.scatteredExpenseseTotal = scatteredExpenseseTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/bedget/bean/DesignestimatedetailEntity.java <==
package com.ejianc.business.bedget.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计概算子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_designestimatedetail")
public class DesignestimatedetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="tid")
    private java.lang.String tid; // 表格行id
    @TableField(value="tpid")
    private java.lang.String tpid; // 表格行父id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="name")
    private java.lang.String name; // 名称
    @TableField(value="project_cost")
    private java.math.BigDecimal projectCost; // 项目造价
    @TableField(value="cost_percent")
    private java.math.BigDecimal costPercent; // 造价占比
    @TableField(value="project_scale")
    private BigDecimal projectScale; // 工程规模
    @TableField(value="unit_cost")
    private java.lang.String unitCost; // 单位造价
    @TableField(value="budge_total")
    private java.math.BigDecimal budgeTotal; // 预算书合计
    @TableField(value="labor_cost")
    private java.math.BigDecimal laborCost; // 人工费
    @TableField(value="material_cost")
    private java.math.BigDecimal materialCost; // 材料费
    @TableField(value="machinery_cost")
    private java.math.BigDecimal machineryCost; // 机械费
    @TableField(value="business_manager_cost")
    private java.math.BigDecimal businessManagerCost; // 企业管理费
    @TableField(value="profit")
    private java.math.BigDecimal profit; // 利润
    @TableField(value="measure_items_total")
    private java.math.BigDecimal measureItemsTotal; // 措施项目合计
    @TableField(value="safe_civilized_construction_cost")
    private java.math.BigDecimal safeCivilizedConstructionCost; // 安全文明施工费
    @TableField(value="transport_consume_cost")
    private java.math.BigDecimal transportConsumeCost; // 运输消纳费
    @TableField(value="scattered_expensese_total")
    private java.math.BigDecimal scatteredExpenseseTotal; // 零星费用合计
    @TableField(value="fees_total")
    private java.math.BigDecimal feesTotal; // 规费合计
    @TableField(value="tax_total")
    private java.math.BigDecimal taxTotal; // 税金合计
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="code")
    private java.lang.String code; // 编码
    @TableField(value="son_item_code")
    private java.lang.String sonItemCode; // 子目编码
    @TableField(value="son_item_name")
    private java.lang.String sonItemName; // 子目名称
    @TableField(value="innercode")
    private String innercode; // 内码


    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 表格行id
     */
    public java.lang.String getTid() {
        return tid;
    }

    /**
     * 表格行id
     */
    public void setTid(java.lang.String tid) {
        this.tid = tid;
    }
    /**
     * 表格行父id
     */
    public java.lang.String getTpid() {
        return tpid;
    }

    /**
     * 表格行父id
     */
    public void setTpid(java.lang.String tpid) {
        this.tpid = tpid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 项目造价
     */
    public java.math.BigDecimal getProjectCost() {
        return projectCost;
    }

    /**
     * 项目造价
     */
    public void setProjectCost(java.math.BigDecimal projectCost) {
        this.projectCost = projectCost;
    }
    /**
     * 造价占比
     */
    public java.math.BigDecimal getCostPercent() {
        return costPercent;
    }

    /**
     * 造价占比
     */
    public void setCostPercent(java.math.BigDecimal costPercent) {
        this.costPercent = costPercent;
    }
    /**
     * 工程规模
     */
    public BigDecimal getProjectScale() {
        return projectScale;
    }

    /**
     * 工程规模
     */
    public void setProjectScale(BigDecimal projectScale) {
        this.projectScale = projectScale;
    }
    /**
     * 单位造价
     */
    public java.lang.String getUnitCost() {
        return unitCost;
    }

    /**
     * 单位造价
     */
    public void setUnitCost(java.lang.String unitCost) {
        this.unitCost = unitCost;
    }
    /**
     * 预算书合计
     */
    public java.math.BigDecimal getBudgeTotal() {
        return budgeTotal;
    }

    /**
     * 预算书合计
     */
    public void setBudgeTotal(java.math.BigDecimal budgeTotal) {
        this.budgeTotal = budgeTotal;
    }
    /**
     * 人工费
     */
    public java.math.BigDecimal getLaborCost() {
        return laborCost;
    }

    /**
     * 人工费
     */
    public void setLaborCost(java.math.BigDecimal laborCost) {
        this.laborCost = laborCost;
    }
    /**
     * 材料费
     */
    public java.math.BigDecimal getMaterialCost() {
        return materialCost;
    }

    /**
     * 材料费
     */
    public void setMaterialCost(java.math.BigDecimal materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 机械费
     */
    public java.math.BigDecimal getMachineryCost() {
        return machineryCost;
    }

    /**
     * 机械费
     */
    public void setMachineryCost(java.math.BigDecimal machineryCost) {
        this.machineryCost = machineryCost;
    }
    /**
     * 企业管理费
     */
    public java.math.BigDecimal getBusinessManagerCost() {
        return businessManagerCost;
    }

    /**
     * 企业管理费
     */
    public void setBusinessManagerCost(java.math.BigDecimal businessManagerCost) {
        this.businessManagerCost = businessManagerCost;
    }
    /**
     * 利润
     */
    public java.math.BigDecimal getProfit() {
        return profit;
    }

    /**
     * 利润
     */
    public void setProfit(java.math.BigDecimal profit) {
        this.profit = profit;
    }
    /**
     * 措施项目合计
     */
    public java.math.BigDecimal getMeasureItemsTotal() {
        return measureItemsTotal;
    }

    /**
     * 措施项目合计
     */
    public void setMeasureItemsTotal(java.math.BigDecimal measureItemsTotal) {
        this.measureItemsTotal = measureItemsTotal;
    }
    /**
     * 安全文明施工费
     */
    public java.math.BigDecimal getSafeCivilizedConstructionCost() {
        return safeCivilizedConstructionCost;
    }

    /**
     * 安全文明施工费
     */
    public void setSafeCivilizedConstructionCost(java.math.BigDecimal safeCivilizedConstructionCost) {
        this.safeCivilizedConstructionCost = safeCivilizedConstructionCost;
    }
    /**
     * 运输消纳费
     */
    public java.math.BigDecimal getTransportConsumeCost() {
        return transportConsumeCost;
    }

    /**
     * 运输消纳费
     */
    public void setTransportConsumeCost(java.math.BigDecimal transportConsumeCost) {
        this.transportConsumeCost = transportConsumeCost;
    }
    /**
     * 零星费用合计
     */
    public java.math.BigDecimal getScatteredExpenseseTotal() {
        return scatteredExpenseseTotal;
    }

    /**
     * 零星费用合计
     */
    public void setScatteredExpenseseTotal(java.math.BigDecimal scatteredExpenseseTotal) {
        this.scatteredExpenseseTotal = scatteredExpenseseTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }

    public String getSonItemCode() {
        return sonItemCode;
    }

    public void setSonItemCode(String sonItemCode) {
        this.sonItemCode = sonItemCode;
    }

    public String getSonItemName() {
        return sonItemName;
    }

    public void setSonItemName(String sonItemName) {
        this.sonItemName = sonItemName;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }
}
